@@ -35,6 +35,7 @@ class Drission(object):
         """
         self._session = None
         self._driver = None
+        self._debugger = None
         self._proxy = proxy
 
         om = OptionsManager(ini_path) if session_or_options is None or driver_or_options is None else None
@@ -83,45 +84,30 @@ class Drission(object):
         如设置了本地调试浏览器，可自动接入或打开浏览器进程。
         """
         if self._driver is None:
-            if isinstance(self._driver_options, dict):
-                options = _dict_to_chrome_options(self._driver_options)
-            else:
+            if not isinstance(self._driver_options, dict):
                 raise TypeError('Driver options invalid')
 
-            if self._proxy:
+            options = _dict_to_chrome_options(self._driver_options)
+
+            if not self._driver_options.get('debugger_address', None) and self._proxy:
                 options.add_argument(f'--proxy-server={self._proxy["http"]}')
 
             driver_path = self._driver_options.get('driver_path', None) or 'chromedriver'
             chrome_path = self._driver_options.get('binary_location', None) or 'chrome.exe'
 
+            # -----------若指定debug端口且该端口未在使用中，则先启动浏览器进程-----------
             if options.debugger_address and _check_port(options.debugger_address) is False:
                 from subprocess import Popen
-                port = options.debugger_address.split(':')[-1]
+                port = options.debugger_address[options.debugger_address.rfind(':') + 1:]
 
-                Popen(f'{chrome_path} --remote-debugging-port={port}', shell=False)
+                # 启动浏览器进程，同时返回该进程使用的 chrome.exe 路径
+                chrome_path, self._debugger = _create_chrome(chrome_path, port,
+                                                             self._driver_options['arguments'], self._proxy)
 
-            try:
-                self._driver = webdriver.Chrome(driver_path, options=options)
+            # -----------创建WebDriver对象-----------
+            self._driver = _create_driver(chrome_path, driver_path, options)
 
-            except (WebDriverException, SessionNotCreatedException):
-                from .easy_set import get_match_driver
-
-                chrome_path = self._driver_options.get('binary_location', None) or None
-                print('自动下载chromedriver...')
-                driver_path = get_match_driver(chrome_path=chrome_path, check_version=False, show_msg=False)
-
-                if driver_path:
-                    try:
-                        self._driver = webdriver.Chrome(driver_path, options=options)
-                        print('下载完成。')
-                    except:
-                        print('无法启动，请检查chromedriver版本与Chrome是否匹配，并手动设置。')
-                        exit(0)
-                else:
-                    print('无法启动，请检查chromedriver版本与Chrome是否匹配，并手动设置。')
-                    exit(0)
-
-            # 反爬设置
+            # 反反爬设置
             try:
                 self._driver.execute_script('Object.defineProperty(navigator,"webdriver",{get:() => Chrome,});')
             except:
@@ -179,6 +165,41 @@ class Drission(object):
             for cookie in cookies:
                 self.set_cookies(cookie, set_driver=True)
 
+    @property
+    def debugger_progress(self):
+        """调试浏览器进程"""
+        return self._debugger
+
+    def kill_browser(self) -> None:
+        """关闭浏览器进程（如果可以）"""
+        if self.debugger_progress:
+            self.debugger_progress.kill()
+            return
+
+        address = self.driver_options.get('debugger_address', '').split(':')
+        if len(address) == 1:
+            self.close_driver()
+
+        elif len(address) == 2:
+            ip, port = address
+            if ip not in ('127.0.0.1', 'localhost') or not port.isdigit():
+                return
+
+            from os import popen
+            progresses = popen(f'netstat -nao | findstr :{port}').read().split('\n')
+            txt = ''
+            for progress in progresses:
+                if 'LISTENING' in progress:
+                    txt = progress
+                    break
+
+            if not txt:
+                return
+
+            pid = txt[txt.rfind(' ') + 1:]
+            if popen(f'tasklist | findstr {pid}').read().lower().startswith('chrome.exe'):
+                popen(f'taskkill /pid {pid} /F')
+
     def set_cookies(self,
                     cookies: Union[RequestsCookieJar, list, tuple, str, dict],
                     set_session: bool = False,
@@ -240,6 +261,10 @@ class Drission(object):
                 self.driver.add_cookie(cookie)
 
     def _set_session(self, data: dict) -> None:
+        """根据传入字典对session进行设置    \n
+        :param data: session配置字典
+        :return: None
+        """
         if self._session is None:
             self._session = Session()
 
@@ -326,7 +351,7 @@ class Drission(object):
 
 
 def _check_port(debugger_address: str) -> Union[bool, None]:
-    """检查端口是否可用                               \n
+    """检查端口是否被占用                               \n
     :param debugger_address: 浏览器地址及端口
     :return: bool
     """
@@ -345,3 +370,89 @@ def _check_port(debugger_address: str) -> Union[bool, None]:
         return True
     except socket.error:
         return False
+    finally:
+        if s:
+            s.close()
+
+
+def _create_chrome(chrome_path: str, port: str, args: list, proxy: dict) -> tuple:
+    """创建 chrome 进程                          \n
+    :param chrome_path: chrome.exe 路径
+    :param port: 进程运行的端口号
+    :param args: chrome 配置参数
+    :return: chrome.exe 路径和进程对象组成的元组
+    """
+    from subprocess import Popen
+
+    # ----------为路径加上双引号，避免路径中的空格产生异常----------
+    args1 = []
+    for arg in args:
+        if arg.startswith(('--user-data-dir', '--disk-cache-dir')):
+            index = arg.find('=') + 1
+            args1.append(f'{arg[:index]}"{arg[index:].strip()}"')
+        else:
+            args1.append(arg)
+
+    args = ' '.join(set(args1))
+
+    if proxy:
+        args = f'{args} --proxy-server={proxy["http"]}'
+
+    # ----------创建浏览器进程----------
+    try:
+        debugger = Popen(f'{chrome_path} --remote-debugging-port={port} {args}', shell=False)
+
+        if chrome_path == 'chrome.exe':
+            from common import get_exe_path_from_port
+            chrome_path = get_exe_path_from_port(port)
+
+    # 传入的路径找不到，主动在ini文件、注册表、系统变量中找
+    except FileNotFoundError:
+        from DrissionPage.easy_set import _get_chrome_path
+        chrome_path = _get_chrome_path(show_msg=False)
+
+        if not chrome_path:
+            raise FileNotFoundError('无法找到chrome.exe路径，请手动配置。')
+
+        debugger = Popen(f'"{chrome_path}" --remote-debugging-port={port} {args}', shell=False)
+
+    return chrome_path, debugger
+
+
+def _create_driver(chrome_path: str, driver_path: str, options: Options) -> WebDriver:
+    """创建 WebDriver 对象                            \n
+    :param chrome_path: chrome.exe 路径
+    :param driver_path: chromedriver.exe 路径
+    :param options: Options 对象
+    :return: WebDriver 对象
+    """
+    try:
+        return webdriver.Chrome(driver_path, options=options)
+
+    # 若版本不对，获取对应 chromedriver 再试
+    except (WebDriverException, SessionNotCreatedException):
+        from .easy_set import get_match_driver
+        chrome_path = None if chrome_path == 'chrome.exe' else chrome_path
+        driver_path = get_match_driver(chrome_path=chrome_path, check_version=False, show_msg=False)
+
+        if driver_path:
+            try:
+                return webdriver.Chrome(driver_path, options=options)
+            except:
+                pass
+
+        # 当找不到 driver 且 chrome_path 为 None 时，说明安装的版本过高，改在系统路径中查找
+        elif chrome_path is None and driver_path is None:
+            from DrissionPage.easy_set import _get_chrome_path
+            chrome_path = _get_chrome_path(show_msg=False, from_ini=False, from_regedit=False)
+            driver_path = get_match_driver(chrome_path=chrome_path, check_version=False, show_msg=False)
+
+            if driver_path:
+                options.binary_location = chrome_path
+                try:
+                    return webdriver.Chrome(driver_path, options=options)
+                except:
+                    pass
+
+    print('无法启动，请检查chromedriver版本与Chrome是否匹配，并手动设置。')
+    exit(0)
