@@ -23,6 +23,7 @@ class DriverElement(DrissionElement):
 
     def __init__(self, ele: WebElement, page=None):
         super().__init__(ele, page)
+        self._select = None
 
     def __repr__(self):
         attrs = [f"{attr}='{self.attrs[attr]}'" for attr in self.attrs]
@@ -55,7 +56,7 @@ class DriverElement(DrissionElement):
     @property
     def tag(self) -> str:
         """返回元素类型"""
-        return self._inner_ele.tag_name
+        return self._inner_ele.tag_name.lower()
 
     @property
     def attrs(self) -> dict:
@@ -121,7 +122,8 @@ class DriverElement(DrissionElement):
         return self._get_brother(1, 'ele', 'prev')
 
     @property
-    def comments(self):
+    def comments(self) -> list:
+        """返回元素注释文本组成的列表"""
         return self.eles('xpath:.//comment()')
 
     # -----------------driver独占属性-------------------
@@ -158,7 +160,19 @@ class DriverElement(DrissionElement):
         """返回当前元素的::after伪元素内容"""
         return self.get_style_property('content', 'after')
 
+    @property
+    def select(self):
+        """返回专门处理下拉列表的Select类，非下拉列表元素返回False"""
+        if self._select is None:
+            if self.tag != 'select':
+                self._select = False
+            else:
+                self._select = Select(self)
+
+        return self._select
+
     # -----------------共有函数-------------------
+
     def texts(self, text_node_only: bool = False) -> list:
         """返回元素内所有直接子节点的文本，包括元素和文本节点   \n
         :param text_node_only: 是否只返回文本节点
@@ -324,14 +338,14 @@ class DriverElement(DrissionElement):
 
         return None if r == 'none' else r
 
-    def click(self, by_js=None) -> bool:
+    def click(self, by_js: bool = None) -> bool:
         """点击元素                                                                      \n
-        尝试点击10次，若都失败就改用js点击                                                  \n
+        尝试点击3次，若都失败就改用js点击                                                  \n
         :param by_js: 是否用js点击，为True时直接用js点击，为False时重试失败也不会改用js
         :return: 是否点击成功
         """
         if not by_js:
-            for _ in range(10):
+            for _ in range(3):
                 try:
                     self.inner_ele.click()
                     return True
@@ -345,17 +359,45 @@ class DriverElement(DrissionElement):
 
         return False
 
-    def input(self, value: str, clear: bool = True) -> bool:
-        """输入文本                          \n
-        :param value: 文本值
+    def click_at(self, x: Union[int, str] = None, y: Union[int, str] = None, by_js=False) -> None:
+        """带偏移量点击本元素，相对于左上角坐标。不传入x或y值时点击元素中点    \n
+        :param x: 相对元素左上角坐标的x轴偏移量
+        :param y: 相对元素左上角坐标的y轴偏移量
+        :param by_js: 是否用js点击
+        :return: None
+        """
+        if by_js:
+            x = self.location['x'] + int(x) if x is not None else self.location['x'] + self.size['width'] // 2
+            y = self.location['y'] + int(y) if y is not None else self.location['y'] + self.size['height'] // 2
+            js = f"""
+            var ev = document.createEvent('HTMLEvents'); 
+            ev.clientX = {x};
+            ev.clientY = {y};
+            ev.initEvent('click', false, true);
+            arguments[0].dispatchEvent(ev);
+            """
+            self.run_script(js)
+
+        else:
+            x = int(x) if x is not None else self.size['width'] // 2
+            y = int(y) if y is not None else self.size['height'] // 2
+
+            from selenium.webdriver import ActionChains
+            ActionChains(self.page.driver).move_to_element_with_offset(self.inner_ele, x, y).click().perform()
+
+    def input(self, value: Union[str, tuple], clear: bool = True) -> bool:
+        """输入文本或组合键                          \n
+        :param value: 文本值或按键组合
         :param clear: 输入前是否清空文本框
         :return: 是否输入成功
         """
         try:
             if clear:
                 self.clear()
-            self.inner_ele.send_keys(value)
+
+            self.inner_ele.send_keys(*value)
             return True
+
         except Exception as e:
             print(e)
             return False
@@ -375,7 +417,7 @@ class DriverElement(DrissionElement):
     def clear(self) -> None:
         """清空元素文本"""
         self.run_script("arguments[0].value=''")
-        # self.ele.clear()
+        # self.inner_ele.clear()
 
     def is_selected(self) -> bool:
         """是否选中"""
@@ -406,7 +448,8 @@ class DriverElement(DrissionElement):
         name = filename or self.tag
         path = Path(path).absolute()
         path.mkdir(parents=True, exist_ok=True)
-        name = get_available_file_name(str(path), f'{name}.png')
+        name = f'{name}.png' if not name.endswith('.png') else name
+        name = get_available_file_name(str(path), name)
 
         # 等待元素加载完成
         if self.tag == 'img':
@@ -420,29 +463,27 @@ class DriverElement(DrissionElement):
 
         return img_path
 
-    def select(self, text: str) -> bool:
-        """选择下拉列表中子元素       \n
-        :param text: 要选择的文本
-        :return: 是否选择成功
-        """
-        from selenium.webdriver.support.select import Select
-        ele = Select(self.inner_ele)
-
-        try:
-            ele.select_by_visible_text(text)
-            return True
-        except Exception as e:
-            print(e)
-            return False
-
-    def set_attr(self, attr: str, value: str) -> bool:
-        """设置元素属性          \n
-        :param attr: 属性名
+    def set_property(self, prop: str, value: str) -> bool:
+        """设置元素property属性          \n
+        :param prop: 属性名
         :param value: 属性值
         :return: 是否设置成功
         """
         try:
-            self.run_script(f"arguments[0].{attr} = '{value}';")
+            value = value.replace("'", "\\'")
+            self.run_script(f"arguments[0].{prop}='{value}';")
+            return True
+        except:
+            return False
+
+    def set_attr(self, attr: str, value: str) -> bool:
+        """设置元素attribute参数          \n
+        :param attr: 参数名
+        :param value: 参数值
+        :return: 是否设置成功
+        """
+        try:
+            self.run_script(f"arguments[0].setAttribute(arguments[1], arguments[2]);", attr, value)
             return True
         except:
             return False
@@ -532,12 +573,14 @@ class DriverElement(DrissionElement):
             if(nth>1){path = '/' + tag + '[' + nth + ']' + path;}
                     else{path = '/' + tag + path;}'''
             txt5 = '''return path;'''
+
         elif mode == 'css':
             txt1 = ''
             # txt2 = '''return '#' + el.id + path;'''
             txt3 = ''
             txt4 = '''path = '>' + ":nth-child(" + nth + ")" + path;'''
             txt5 = '''return path.substr(1);'''
+
         else:
             raise ValueError(f"Argument mode can only be 'xpath' or 'css', not '{mode}'.")
 
@@ -745,3 +788,157 @@ class ElementsByXpath(object):
                      else format_html(x)
                      for x in get_nodes(the_node, xpath_txt=self.xpath)
                      if x != '\n'])
+
+
+class Select(object):
+    """Select 类专门用于处理 d 模式下 select 标签"""
+
+    def __init__(self, ele: DriverElement):
+        """初始化                      \n
+        :param ele: select 元素对象
+        """
+        if ele.tag != 'select':
+            raise TypeError(f"Select only works on <select> elements, not on {ele.tag}")
+
+        from selenium.webdriver.support.select import Select as sl
+        self.inner_ele = ele
+        self.select_ele = sl(ele.inner_ele)
+
+    def __call__(self,
+                 text_value_index: Union[str, int, list, tuple] = None,
+                 para_type: str = 'text',
+                 deselect: bool = False) -> bool:
+        """选定或取消选定下拉列表中子元素                                                             \n
+        :param text_value_index: 根据文本、值选或序号择选项，若允许多选，传入list或tuple可多选
+        :param para_type: 参数类型，可选 'text'、'value'、'index'
+        :param deselect: 是否取消选择
+        :return: 是否选择成功
+        """
+        return self.select(text_value_index, para_type, deselect)
+
+    @property
+    def is_multi(self) -> bool:
+        """返回是否多选表单"""
+        return self.select_ele.is_multiple
+
+    @property
+    def options(self) -> List[DriverElement]:
+        """返回所有选项元素组成的列表"""
+        return self.inner_ele.eles('tag:option')
+
+    @property
+    def selected_option(self) -> Union[DriverElement, None]:
+        """返回第一个被选中的option元素        \n
+        :return: DriverElement对象或None
+        """
+        ele = self.inner_ele.run_script('return arguments[0].options[arguments[0].selectedIndex];')
+        return None if ele is None else DriverElement(ele, self.inner_ele.page)
+
+    @property
+    def selected_options(self) -> List[DriverElement]:
+        """返回所有被选中的option元素列表        \n
+        :return: DriverElement对象组成的列表
+        """
+        return [x for x in self.options if x.is_selected()]
+
+    def clear(self) -> None:
+        """清除所有已选项"""
+        self.select_ele.deselect_all()
+
+    def select(self,
+               text_value_index: Union[str, int, list, tuple] = None,
+               para_type: str = 'text',
+               deselect: bool = False) -> bool:
+        """选定或取消选定下拉列表中子元素                                                             \n
+        :param text_value_index: 根据文本、值选或序号择选项，若允许多选，传入list或tuple可多选
+        :param para_type: 参数类型，可选 'text'、'value'、'index'
+        :param deselect: 是否取消选择
+        :return: 是否选择成功
+        """
+        if not self.is_multi and isinstance(text_value_index, (list, tuple)):
+            raise TypeError('单选下拉列表不能传入list和tuple')
+
+        if isinstance(text_value_index, (str, int)):
+            try:
+                if para_type == 'text':
+                    if deselect:
+                        self.select_ele.deselect_by_visible_text(text_value_index)
+                    else:
+                        self.select_ele.select_by_visible_text(text_value_index)
+                elif para_type == 'value':
+                    if deselect:
+                        self.select_ele.deselect_by_value(text_value_index)
+                    else:
+                        self.select_ele.select_by_value(text_value_index)
+                elif para_type == 'index':
+                    if deselect:
+                        self.select_ele.deselect_by_index(int(text_value_index))
+                    else:
+                        self.select_ele.select_by_index(int(text_value_index))
+                else:
+                    raise ValueError('para_type参数只能传入"text"、"value"或"index"。')
+                return True
+
+            except:
+                return False
+
+        elif isinstance(text_value_index, (list, tuple)):
+            self.select_multi(text_value_index, para_type, deselect)
+
+        else:
+            raise TypeError('只能传入str、int、list和tuple类型。')
+
+    def select_multi(self,
+                     text_value_index: Union[list, tuple] = None,
+                     para_type: str = 'text',
+                     deselect: bool = False) -> Union[bool, list]:
+        """选定或取消选定下拉列表中多个子元素                                                             \n
+        :param text_value_index: 根据文本、值选或序号择选多项
+        :param para_type: 参数类型，可选 'text'、'value'、'index'
+        :param deselect: 是否取消选择
+        :return: 是否选择成功
+        """
+        if para_type not in ('text', 'value', 'index'):
+            raise ValueError('para_type参数只能传入“text”、“value”或“index”')
+
+        if isinstance(text_value_index, (list, tuple)):
+            fail_list = []
+            for i in text_value_index:
+                if not isinstance(i, (int, str)):
+                    raise TypeError('列表只能由str或int组成')
+
+                if not self.select(i, para_type, deselect):
+                    fail_list.append(i)
+
+            return fail_list or True
+
+        else:
+            raise TypeError('只能传入list或tuple类型。')
+
+    def deselect(self,
+                 text_value_index: Union[str, int, list, tuple] = None,
+                 para_type: str = 'text') -> bool:
+        """取消选定下拉列表中子元素                                                             \n
+        :param text_value_index: 根据文本、值选或序号择选项，若允许多选，传入list或tuple可多选
+        :param para_type: 参数类型，可选 'text'、'value'、'index'
+        :return: 是否选择成功
+        """
+        return self.select(text_value_index, para_type, True)
+
+    def deselect_multi(self,
+                       text_value_index: Union[list, tuple] = None,
+                       para_type: str = 'text') -> Union[bool, list]:
+        """取消选定下拉列表中多个子元素                                                             \n
+        :param text_value_index: 根据文本、值选或序号取消择选多项
+        :param para_type: 参数类型，可选 'text'、'value'、'index'
+        :return: 是否选择成功
+        """
+        return self.select_multi(text_value_index, para_type, True)
+
+    def invert(self) -> None:
+        """反选"""
+        if not self.is_multi:
+            raise NotImplementedError("You may only deselect options of a multi-select")
+
+        for i in self.options:
+            i.click()
