@@ -139,7 +139,7 @@ class DriverPage(object):
         :param interval: 重试间隔（秒）
         :return: 目标url是否可用
         """
-        to_url = quote(url, safe='/:&?=%;#@')
+        to_url = quote(url, safe='/:&?=%;#@+!')
         retry = int(retry) if retry is not None else int(self.retry_times)
         interval = int(interval) if interval is not None else int(self.retry_interval)
 
@@ -149,6 +149,11 @@ class DriverPage(object):
         self._url = to_url
         self._url_available = self._try_to_connect(to_url, times=retry, interval=interval, show_errmsg=show_errmsg)
 
+        try:
+            self._driver.execute_script('Object.defineProperty(navigator,"webdriver",{get:() => Chrome,});')
+        except:
+            pass
+
         return self._url_available
 
     def ele(self,
@@ -416,18 +421,18 @@ class DriverPage(object):
         tab = self.driver.window_handles[tab] if isinstance(tab, int) else tab
         self.driver.switch_to.window(tab)
 
-    def to_iframe(self, loc_or_ele: Union[int, str, tuple, WebElement, DriverElement] = 'main') -> None:
-        """跳转到iframe                                                                         \n
-        可接收iframe序号(0开始)、id或name、查询字符串、loc元组、WebElement对象、DriverElement对象，  \n
-        传入'main'跳到最高层，传入'parent'跳到上一层                                               \n
-        示例：                                                                                   \n
-            to_iframe('tag:iframe')    - 通过传入iframe的查询字符串定位                            \n
-            to_iframe('iframe_id')     - 通过iframe的id属性定位                                   \n
-            to_iframe('iframe_name')   - 通过iframe的name属性定位                                 \n
-            to_iframe(iframe_element)  - 通过传入元素对象定位                                      \n
-            to_iframe(0)               - 通过iframe的序号定位                                     \n
-            to_iframe('main')          - 跳到最高层                                               \n
-            to_iframe('parent')        - 跳到上一层                                               \n
+    def to_frame(self, loc_or_ele: Union[int, str, tuple, WebElement, DriverElement] = 'main') -> None:
+        """跳转到frame                                                                       \n
+        可接收frame序号(0开始)、id或name、查询字符串、loc元组、WebElement对象、DriverElement对象，  \n
+        传入'main'跳到最高层，传入'parent'跳到上一层                                             \n
+        示例：                                                                                \n
+            to_frame('tag:iframe')    - 通过传入frame的查询字符串定位                            \n
+            to_frame('iframe_id')     - 通过frame的id属性定位                                   \n
+            to_frame('iframe_name')   - 通过frame的name属性定位                                 \n
+            to_frame(iframe_element)  - 通过传入元素对象定位                                     \n
+            to_frame(0)               - 通过frame的序号定位                                     \n
+            to_frame('main')          - 跳到最高层                                              \n
+            to_frame('parent')        - 跳到上一层                                              \n
         :param loc_or_ele: iframe的定位信息
         :return: None
         """
@@ -445,7 +450,7 @@ class DriverPage(object):
                 self.driver.switch_to.parent_frame()
 
             # 传入id或name
-            elif ':' not in loc_or_ele and '=' not in loc_or_ele:
+            elif ':' not in loc_or_ele and '=' not in loc_or_ele and not loc_or_ele.startswith(('#', '.')):
                 self.driver.switch_to.frame(loc_or_ele)
 
             # 传入控制字符串
@@ -486,8 +491,8 @@ class DriverPage(object):
         ele.run_script("arguments[0].scrollIntoView();")
 
     def scroll_to(self, mode: str = 'bottom', pixel: int = 300) -> None:
-        """按参数指示方式滚动页面                                                                           \n
-        :param mode: 可选滚动方向：'top', 'bottom', 'rightmost', 'leftmost', 'up', 'down', 'left', 'right'
+        """按参数指示方式滚动页面                                                                                    \n
+        :param mode: 可选滚动方向：'top', 'bottom', 'half', 'rightmost', 'leftmost', 'up', 'down', 'left', 'right'
         :param pixel: 滚动的像素
         :return: None
         """
@@ -498,6 +503,10 @@ class DriverPage(object):
             self.driver.execute_script(
                 "window.scrollTo(document.documentElement.scrollLeft,document.body.scrollHeight);")
 
+        elif mode == 'half':
+            self.driver.execute_script(
+                "window.scrollTo(document.documentElement.scrollLeft,document.body.scrollHeight/2);")
+
         elif mode == 'rightmost':
             self.driver.execute_script("window.scrollTo(document.body.scrollWidth,document.documentElement.scrollTop);")
 
@@ -518,7 +527,7 @@ class DriverPage(object):
 
         else:
             raise ValueError(
-                "Argument mode can only be 'top', 'bottom', 'rightmost', 'leftmost', 'up', 'down', 'left', 'right'.")
+                "Argument mode can only be 'top', 'bottom', 'half', 'rightmost', 'leftmost', 'up', 'down', 'left', 'right'.")
 
     def refresh(self) -> None:
         """刷新当前页面"""
@@ -529,16 +538,19 @@ class DriverPage(object):
         self.driver.back()
 
     def set_window_size(self, x: int = None, y: int = None) -> None:
-        """设置浏览器窗口大小，默认最大化  \n
+        """设置浏览器窗口大小，默认最大化，任一参数为0最小化  \n
         :param x: 浏览器窗口高
         :param y: 浏览器窗口宽
         :return: None
         """
-        if not x and not y:
+        if x is None and y is None:
             self.driver.maximize_window()
 
+        elif x == 0 or y == 0:
+            self.driver.minimize_window()
+
         else:
-            if x <= 0 or y <= 0:
+            if x < 0 or y < 0:
                 raise ValueError('Arguments x and y must greater than 0.')
 
             new_x = x or self.driver.get_window_size()['width']
